@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* preferences.c - setting the preferences
 
-   Copyright (C) 1998 - 2002 Free Software Foundation
+   Copyright (C) 1998 - 2003 Free Software Foundation
 
    GHex is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -27,6 +27,7 @@
 #include <libgnomeprintui/gnome-font-dialog.h>
 
 #include "ghex.h"
+#include "gnome-print-font-picker.h"
 
 static void select_font_cb(GtkWidget *w, const gchar *font_name, GtkDialog *pbox);
 static void apply_changes_cb(PropertyUI *pui);
@@ -289,11 +290,10 @@ create_prefs_dialog()
 					 GTK_FILL, GTK_FILL,
 					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
-	pui->df_button = gnome_font_picker_new();
-	gnome_font_picker_set_mode (GNOME_FONT_PICKER (pui->df_button),
-								GNOME_FONT_PICKER_MODE_FONT_INFO);
-	gnome_font_picker_fi_set_use_font_in_label (GNOME_FONT_PICKER (pui->df_button), TRUE, 14);
-	gnome_font_picker_fi_set_show_size (GNOME_FONT_PICKER (pui->df_button), TRUE);
+	pui->df_button = gnome_print_font_picker_new();
+	gnome_print_font_picker_set_mode (GNOME_PRINT_FONT_PICKER (pui->df_button), GNOME_PRINT_FONT_PICKER_MODE_FONT_INFO);
+	gnome_print_font_picker_fi_set_use_font_in_label (GNOME_PRINT_FONT_PICKER (pui->df_button), TRUE, 14);
+	gnome_print_font_picker_fi_set_show_size (GNOME_PRINT_FONT_PICKER (pui->df_button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (pui->df_button), "font_set",
 						GTK_SIGNAL_FUNC (select_font_cb), pui->pbox);
 	pui->df_label = gtk_label_new("");
@@ -322,11 +322,10 @@ create_prefs_dialog()
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
 					 GTK_FILL, GTK_FILL,
 					 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	pui->hf_button = gnome_font_picker_new();
-	gnome_font_picker_set_mode (GNOME_FONT_PICKER (pui->hf_button),
-								GNOME_FONT_PICKER_MODE_FONT_INFO);
-	gnome_font_picker_fi_set_use_font_in_label (GNOME_FONT_PICKER (pui->hf_button), TRUE, 14);
-	gnome_font_picker_fi_set_show_size (GNOME_FONT_PICKER (pui->hf_button), TRUE);
+	pui->hf_button = gnome_print_font_picker_new();
+	gnome_print_font_picker_set_mode (GNOME_PRINT_FONT_PICKER (pui->hf_button), GNOME_PRINT_FONT_PICKER_MODE_FONT_INFO);
+	gnome_print_font_picker_fi_set_use_font_in_label (GNOME_PRINT_FONT_PICKER (pui->hf_button), TRUE, 14);
+	gnome_print_font_picker_fi_set_show_size (GNOME_PRINT_FONT_PICKER (pui->hf_button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (pui->hf_button), "font_set",
 						GTK_SIGNAL_FUNC (select_font_cb), pui->pbox);
 	pui->hf_label = gtk_label_new("");
@@ -432,11 +431,15 @@ void set_prefs(PropertyUI *pui) {
 		gtk_widget_set_sensitive(pui->format, TRUE);
 	}
 
-	gnome_font_picker_set_font_name(GNOME_FONT_PICKER(pui->hf_button),
-									header_font_name);
-
-	gnome_font_picker_set_font_name(GNOME_FONT_PICKER(pui->df_button),
-									data_font_name);
+	if(header_font_name)
+		gnome_print_font_picker_set_font_name(GNOME_PRINT_FONT_PICKER(pui->hf_button),
+										header_font_name);
+	if(data_font_name)
+		gnome_print_font_picker_set_font_name(GNOME_PRINT_FONT_PICKER(pui->df_button),
+										data_font_name);
+	if(def_font_name)
+		gnome_font_picker_set_font_name(GNOME_FONT_PICKER(pui->font_button),
+										def_font_name);
 
 	gtk_dialog_set_default_response(GTK_DIALOG(pui->pbox), GTK_RESPONSE_CANCEL);
 	gtk_dialog_set_response_sensitive(GTK_DIALOG(pui->pbox), GTK_RESPONSE_OK, FALSE);
@@ -542,7 +545,7 @@ static void apply_changes_cb(PropertyUI *pui) {
 	if(strcmp(gnome_font_picker_get_font_name(GNOME_FONT_PICKER
 											  (pui->font_button)), def_font_name) != 0) {
 		if((new_metrics = gtk_hex_load_font(gnome_font_picker_get_font_name
-									 (GNOME_FONT_PICKER(pui->font_button)))) != NULL) {
+											(GNOME_FONT_PICKER(pui->font_button)))) != NULL) {
 			new_desc = pango_font_description_from_string (gnome_font_picker_get_font_name (GNOME_FONT_PICKER (pui->font_button)));
 			if (def_metrics)
 				pango_font_metrics_unref (def_metrics);
@@ -565,10 +568,10 @@ static void apply_changes_cb(PropertyUI *pui) {
 
 	if(data_font_name)
 		g_free(data_font_name);
-	data_font_name = g_strdup (gnome_font_picker_get_font_name (GNOME_FONT_PICKER (pui->df_button)));
+	data_font_name = g_strdup (gnome_print_font_picker_get_font_name (GNOME_PRINT_FONT_PICKER (pui->df_button)));
 	if(header_font_name)
 		g_free(header_font_name);
-	header_font_name = g_strdup (gnome_font_picker_get_font_name (GNOME_FONT_PICKER (pui->hf_button)));
+	header_font_name = g_strdup (gnome_print_font_picker_get_font_name (GNOME_PRINT_FONT_PICKER (pui->hf_button)));
 
 	save_configuration();
 }
